/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.nachrichten.postfach.bayernid.proxy.mock;

import static com.github.tomakehurst.wiremock.client.WireMock.*;

import com.github.tomakehurst.wiremock.junit5.WireMockRuntimeInfo;

import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
public class MockBayernIdInitializer {

	private static final String RESPONSE_TEMPLATE = """
			<SOAP-ENV:Envelope xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/">
				<SOAP-ENV:Header/>
				<SOAP-ENV:Body>
					<ns2:sendBspNachrichtNativeOutput xmlns:ns2="urn:akdb:bsp:postkorb:komm:webservice">
						<bspQuittung>%s</bspQuittung>
					</ns2:sendBspNachrichtNativeOutput>
				</SOAP-ENV:Body>
			</SOAP-ENV:Envelope>
						""";
	public static final String BSP_NACHRICHT_SUCCESS = "&lt;?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?&gt;&lt;BspQuittung version=\"1.5\" fassung=\"2020-03-15\" xmlns=\"http://www.akdb.de/egov/bsp/nachrichten\"&gt;&lt;AnnahmeErfolgreich&gt;true&lt;/AnnahmeErfolgreich&gt;&lt;ErgebnisStatus&gt;&lt;Tabelle&gt;9006&lt;/Tabelle&gt;&lt;Schluessel&gt;0&lt;/Schluessel&gt;&lt;/ErgebnisStatus&gt;&lt;ErgaenzendeHinweise&gt;Nachricht wurde angenommen&lt;/ErgaenzendeHinweise&gt;&lt;/BspQuittung&gt;";
	public static final String BSP_NACHRICHT_ERROR = "&lt;?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"yes\"?&gt;&lt;BspQuittung version=\"1.5\" fassung=\"2020-03-15\" xmlns=\"http://www.akdb.de/egov/bsp/nachrichten\"&gt;&lt;AnnahmeErfolgreich&gt;false&lt;/AnnahmeErfolgreich&gt;&lt;ErgebnisStatus&gt;&lt;Tabelle&gt;9006&lt;/Tabelle&gt;&lt;Schluessel&gt;31&lt;/Schluessel&gt;&lt;/ErgebnisStatus&gt;&lt;ErgaenzendeHinweise&gt;Unzulässiger Nachrichteninhalt&lt;/ErgaenzendeHinweise&gt;&lt;/BspQuittung&gt;";

	public final WireMockRuntimeInfo wmRuntimeInfo;

	public void createResponseOk() {
		wmRuntimeInfo.getWireMock().register(
				post("/").willReturn(aResponse()
						.withStatus(200)
						.withHeader("Content-Type", "text/xml")
						.withHeader("charset", "UTF-8")
						.withBody(RESPONSE_TEMPLATE.formatted(BSP_NACHRICHT_SUCCESS))
				));
	}

	public void createResponseError() {
		wmRuntimeInfo.getWireMock().register(
				post("/").willReturn(aResponse()
						.withStatus(200)
						.withHeader("Content-Type", "text/xml")
						.withHeader("charset", "UTF-8")
						.withBody(RESPONSE_TEMPLATE.formatted(BSP_NACHRICHT_ERROR))
				));
	}

	public void createResponseWithException() {
		wmRuntimeInfo.getWireMock().register(
				post("/").willReturn(aResponse()
						.withStatus(200)
						.withHeader("Content-Type", "text/xml")
						.withHeader("charset", "UTF-8")
						.withBody("Internal Server Error")
				));
	}

	public void create500Response() {
		wmRuntimeInfo.getWireMock().register(
				post("/").willReturn(aResponse()
						.withStatus(500)
						.withBody("Internal Server Error")
				));
	}

}
